@@ -960,7 +960,7 @@ class TestHandlePatch:
     def test_handle_patch_unknown(self):
         with pytest.raises(Exception) as excinfo:
             tuxsuite.build.handle_patch("/tmp/patch")
-        assert "series file not found in patch directory" in str(excinfo)
+        assert "No such file or directory" in str(excinfo)
 
     def test_handle_patch_mbox(self, mocker, sample_patch, sample_patch_file):
         guess = mocker.patch(
@@ -1069,6 +1069,7 @@ class TestTest:
                 "kernel": test_attrs["kernel"],
                 "device": test_attrs["device"],
                 "ap_romfw": None,
+                "dtb": None,
                 "mcp_fw": None,
                 "mcp_romfw": None,
                 "parameters": [],
