@@ -418,10 +418,103 @@ def plan_json():
             ],
             "next": None,
         },
+        "oebuilds": {"count": 0, "results": [], "next": None},
     }
     return json.dumps(plan).encode("utf-8")
 
 
+@pytest.fixture
+def bake_plan_json():
+    bake_plan = {
+        "project": "tuxsuite/alok",
+        "uid": "29EbSmPfjpbYQj8ZuaBpsiA8CbW",
+        "name": "armv7 validation",
+        "description": "Build and test linux kernel for armv7",
+        "user": "alok.ranjan@linaro.org",
+        "user_agent": "tuxsuite/0.43.10",
+        "provisioning_time": "2022-05-16T06:06:33.830964",
+        "oebuilds": {
+            "count": 2,
+            "results": [
+                {
+                    "project": "tuxsuite/alok",
+                    "uid": "29EbSyjM7FZgX1X2FDvpq0hxomz",
+                    "plan": "29EbSmPfjpbYQj8ZuaBpsiA8CbW",
+                    "distro": "rpb",
+                    "machine": "ledge-multi-armv7",
+                    "container": "ubuntu-20.04",
+                    "environment": {},
+                    "local_conf": [],
+                    "bblayers_conf": [],
+                    "artifacts": [],
+                    "target": "rpb-console-image rpb-console-image-test rpb-desktop-image rpb-desktop-image-test",
+                    "envsetup": "setup-environment",
+                    "user": "alok.ranjan@linaro.org",
+                    "user_agent": "tuxsuite/0.43.10",
+                    "download_url": "https://oebuilds.tuxbuild.com/29EbSyjM7FZgX1X2FDvpq0hxomz/",
+                    "sources": {
+                        "repo": {
+                            "branch": "qcom/dunfell",
+                            "manifest": "default.xml",
+                            "url": "https://github.com/96boards/oe-rpb-manifest.git",
+                        }
+                    },
+                    "state": "finished",
+                    "result": "fail",
+                    "waited_by": [],
+                    "errors_count": 0,
+                    "warnings_count": 0,
+                    "running_time": "2022-05-16T06:09:04.713320",
+                    "finished_time": "2022-05-16T06:09:46.534596",
+                    "manifest_file": "None",
+                    "provisioning_time": "2022-05-16T06:06:35.312535",
+                    "duration": 43,
+                    "status_message": "",
+                },
+                {
+                    "project": "tuxsuite/alok",
+                    "uid": "29EbSycpmLu8Nut5SoZFCwJaRER",
+                    "plan": "29EbSmPfjpbYQj8ZuaBpsiA8CbW",
+                    "distro": "rpb",
+                    "machine": "dragonboard-845c",
+                    "container": "ubuntu-20.04",
+                    "environment": {},
+                    "local_conf": [],
+                    "bblayers_conf": [],
+                    "artifacts": [],
+                    "target": "rpb-console-image rpb-console-image-test rpb-desktop-image rpb-desktop-image-test",
+                    "envsetup": "setup-environment",
+                    "user": "alok.ranjan@linaro.org",
+                    "user_agent": "tuxsuite/0.43.10",
+                    "download_url": "https://oebuilds.tuxbuild.com/29EbSycpmLu8Nut5SoZFCwJaRER/",
+                    "sources": {
+                        "repo": {
+                            "branch": "qcom/dunfell",
+                            "manifest": "default.xml",
+                            "url": "https://github.com/96boards/oe-rpb-manifest.git",
+                        }
+                    },
+                    "state": "finished",
+                    "result": "pass",
+                    "waited_by": [],
+                    "errors_count": 0,
+                    "warnings_count": 0,
+                    "running_time": "2022-05-16T06:09:04.709211",
+                    "finished_time": "2022-05-16T08:06:04.740891",
+                    "manifest_file": "None",
+                    "provisioning_time": "2022-05-16T06:06:35.312683",
+                    "duration": 7021,
+                    "status_message": "",
+                },
+            ],
+            "next": None,
+        },
+        "builds": {"count": 0, "results": [], "next": None},
+        "tests": {"count": 0, "results": [], "next": None},
+    }
+    return json.dumps(bake_plan).encode("utf-8")
+
+
 @pytest.fixture
 def plan_list_json():
     plan_list = {
@@ -504,3 +597,37 @@ def test_plan_handle_list(mocker, plan_list_json, config, response, monkeypatch)
     with pytest.raises(NotImplementedError):
         handle_list(options, config)
     assert list_req.call_count == 1
+
+
+def test_bake_plan_handle_get(mocker, bake_plan_json, config, response, monkeypatch):
+    monkeypatch.setattr(
+        sys, "argv", ["tuxsuite", "plan", "get", "29EbSmPfjpbYQj8ZuaBpsiA8CbW"]
+    )
+    options = setup_parser(config.group, config.project).parse_args()
+    response.status_code = 200
+    response._content = bake_plan_json
+    get_req = mocker.patch("requests.get", return_value=response)
+    result = handle_get(options, config)
+    assert result == 0
+    assert get_req.call_count == 1
+
+    # Test json out
+    monkeypatch.setattr(
+        sys,
+        "argv",
+        ["tuxsuite", "plan", "get", "29EbSmPfjpbYQj8ZuaBpsiA8CbW", "--json"],
+    )
+    options = setup_parser(config.group, config.project).parse_args()
+    response.status_code = 200
+    response._content = bake_plan_json
+    get_req = mocker.patch("requests.get", return_value=response)
+    result = handle_get(options, config)
+    assert result == 0
+    assert get_req.call_count == 1
+
+    # Test failure case when the response is not 200
+    response.status_code = 500
+    get_req = mocker.patch("requests.get", return_value=response)
+    with pytest.raises(NotImplementedError):
+        result = handle_get(options, config)
+    assert get_req.call_count == 1
