@@ -13,6 +13,7 @@ import sys
 import shutil
 import subprocess
 import tarfile
+import tempfile
 import time
 import tuxsuite.exceptions
 import tuxsuite.requests
@@ -57,26 +58,43 @@ def get_request(url, headers, params=None):
         response.raise_for_status()  # Some unexpected status that's not caught
 
 
+def download_patch_with_b4(patch_path):
+    if shutil.which("b4"):
+        patch_file = tempfile.NamedTemporaryFile(suffix=".mbx").name
+        subprocess.check_output(["b4", "am", "-n", patch_file, patch_path])
+        patch_path = patch_file
+        patch_file = os.path.basename(patch_file)
+        return (patch_file, patch_path)
+    else:
+        print(
+            f"\033[91mERROR: 'b4' not found to download patch from {patch_path}\033[0m"
+        )
+        sys.exit(1)
+
+
 def handle_patch(patch_path):
+    patch_type = None
     patch_is_web_url = False
     patch_content = None
     patch_file = os.path.basename(patch_path)
     if "lore.kernel.org" in patch_path:
-        if shutil.which("b4"):
-            patch_file = f"/tmp/{uuid.uuid4().hex}.mbx"
-            subprocess.check_output(["b4", "am", "-n", patch_file, patch_path])
-            patch_path = patch_file
-            patch_file = os.path.basename(patch_file)
-        else:
-            print(
-                f"\033[91mERROR: 'b4' not found to download patch from {patch_path}\033[0m"
-            )
-            sys.exit(1)
+        patch_file, patch_path = download_patch_with_b4(patch_path)
+
     if urlparse(patch_path).scheme in ["http", "https"]:
+        patch_type = "url"
+    elif os.path.isfile(patch_path):
+        patch_type = "file"
+    elif os.path.isdir(patch_path):
+        patch_type = "dir"
+    else:
+        patch_type = "message-id"
+        patch_file, patch_path = download_patch_with_b4(patch_path)
+
+    if patch_type == "url":
         patch_file = patch_path
         patch_content = b""
         patch_is_web_url = True
-    elif os.path.isfile(patch_path):
+    elif patch_type in ["file", "message-id"]:
         # Rename .mbx to .mbox on the fly.
         if pathlib.Path(patch_path).suffix == ".mbx":
             new_patch_path = os.path.join(
@@ -109,7 +127,7 @@ def handle_patch(patch_path):
             raise Exception("Patch series format unknown")
         with open(patch_path, "rb") as patch:
             patch_content = base64.b64encode(patch.read())
-    else:
+    elif patch_type == "dir":
         if not os.path.exists(os.path.join(patch_path, "series")):
             raise Exception("series file not found in patch directory")
         patch_path = os.path.abspath(patch_path)
@@ -802,6 +820,7 @@ class Test(HeadersMixin):
     device = attrib()
     kernel = attrib(default=None)
     ap_romfw = attrib(default=None)
+    dtb = attrib(default=None)
     mcp_fw = attrib(default=None)
     mcp_romfw = attrib(default=None)
     modules = attrib(default=None)
@@ -830,6 +849,7 @@ class Test(HeadersMixin):
             "device": self.device,
             "kernel": self.kernel,
             "ap_romfw": self.ap_romfw,
+            "dtb": self.dtb,
             "mcp_fw": self.mcp_fw,
             "mcp_romfw": self.mcp_romfw,
             "parameters": self.parameters,
