@@ -490,7 +490,6 @@ def common_options(required):
         option(
             "-p",
             "--patch-series",
-            type=file_or_url,
             default=None,
             help=(
                 "Patches to apply before building the kernel. Accepts patch "
@@ -720,7 +719,7 @@ def build(
         build_params["make_variables"] = make_vars
 
     if patch_series:
-        build_params["patch_series"] = click.format_filename(patch_series)
+        build_params["patch_series"] = patch_series
 
     build_params["no_cache"] = no_cache
     try:
@@ -785,7 +784,7 @@ def build_set(
         build_params["make_variables"] = make_vars
 
     if patch_series:
-        build_params["patch_series"] = click.format_filename(patch_series)
+        build_params["patch_series"] = patch_series
 
     try:
         plan_config = tuxsuite.config.BuildSetConfig(set_name, tux_config)
@@ -850,6 +849,12 @@ def test_options(required):
             default=None,
             type=str,
         ),
+        option(
+            "--dtb",
+            help="URL of the dtb to test",
+            default=None,
+            type=str,
+        ),
         option(
             "--mcp-fw", help="URL of the MCP firmware to test", default=None, type=str
         ),
@@ -971,6 +976,7 @@ def test(
     device,
     kernel,
     ap_romfw,
+    dtb,
     mcp_fw,
     mcp_romfw,
     modules,
@@ -1043,6 +1049,7 @@ def test(
             device=device,
             kernel=kernel,
             ap_romfw=ap_romfw,
+            dtb=dtb,
             mcp_fw=mcp_fw,
             mcp_romfw=mcp_romfw,
             modules=modules,
@@ -1142,7 +1149,6 @@ plan_description = (
 @click.option(
     "-p",
     "--patch-series",
-    type=file_or_url,
     default=None,
     help=(
         "Patches to apply before building the kernel. Accepts patch "
