@@ -1,5 +1,6 @@
 # -*- coding: utf-8 -*-
 
+import sys
 import tuxsuite.cli.colors as colors
 from tuxsuite.cli.requests import get
 
@@ -31,5 +32,5 @@ def fetch_next(cmd_cls, cfg, url, next_token, limit):
     if next_token:
         input(f"\nPress [ENTER] to see next list of {cmd_name}, or Ctrl-C to quit:\n")
     else:
-        exit(0)
+        sys.exit(0)
     return (res, next_token)
